public inbox for gdb-patches@sourceware.org
 help / color / mirror / Atom feed
From: "Sangamesh Mallayya" <sangamesh.swamy@in.ibm.com>
To: "Ulrich Weigand" <uweigand@de.ibm.com>
Cc: gdb-patches@sourceware.org
Subject: Re: set sysroot command on AIX has no effect.
Date: Thu, 13 Oct 2016 17:44:00 -0000	[thread overview]
Message-ID: <OF1BA61B31.92F7DDAC-ON6525804B.00611590-6525804B.0061615B@notes.na.collabserv.com> (raw)
In-Reply-To: <20161013140325.B376810008F@oc8523832656.ibm.com>

[-- Attachment #1: Type: text/plain, Size: 322 bytes --]

Hi Ulrich,


> > Thanks again. Here is the updated patch and looks much better than the
> > previous one.
> 
> Indeed, this looks good to me now.  We still need a ChangeLog entry,
> but apart from that, this is ready to check in.
> 

Please find the ChangeLog & patch file attached.




Thanks,
Sangamesh

[-- Attachment #2: ChangeLog --]
[-- Type: application/octet-stream, Size: 178 bytes --]

	* solib-aix.c (solib_aix_bfd_open): Call solib_find so that sysroot
	path is set properly if program has a dependency on .a archive and
	sysroot is set via set sysroot command.

[-- Attachment #3: sysroot.patch --]
[-- Type: application/octet-stream, Size: 1919 bytes --]

--- ./gdb/solib-aix.c_orig	2016-10-04 03:22:01.000000000 -0500
+++ ./gdb/solib-aix.c	2016-10-13 03:09:26.000000000 -0500
@@ -648,6 +648,8 @@
    char *member_name;
    bfd *archive_bfd, *object_bfd;
    struct cleanup *cleanup;
+   int found_file;
+   char *found_pathname;
  
    if (pathname[path_len - 1] != ')')
      return solib_bfd_open (pathname);
@@ -669,7 +671,13 @@
    member_name = xstrprintf ("%.*s", path_len - filename_len - 2, sep + 1);
    make_cleanup (xfree, member_name);
  
-   archive_bfd = gdb_bfd_open (filename, gnutarget, -1);
+   /* Calling solib_find makes certain that sysroot path is set properly
+      if program has a dependency on .a archive and sysroot is set via
+      set sysroot command.  */
+   found_pathname = solib_find (filename, &found_file);
+   if (found_pathname == NULL)
+       perror_with_name (pathname);
+   archive_bfd = solib_bfd_fopen (found_pathname, found_file);
    if (archive_bfd == NULL)
      {
        warning (_("Could not open `%s' as an executable file: %s"),
@@ -724,12 +732,14 @@
        return NULL;
      }
  
-   /* Override the returned bfd's name with our synthetic name in order
-      to allow commands listing all shared libraries to display that
-      synthetic name.  Otherwise, we would only be displaying the name
-      of the archive member object.  */
+   /* Override the returned bfd's name with the name returned from solib_find
+      along with appended parenthesized member name in order to allow commands
+      listing all shared libraries to display. 
+      Otherwise, we would only be displaying the name of the archive member
+      object.  */
    xfree (bfd_get_filename (object_bfd));
-   object_bfd->filename = xstrdup (pathname);
+   object_bfd->filename = xstrprintf ("%s%s",
+                                      bfd_get_filename (archive_bfd), sep);
  
    gdb_bfd_unref (archive_bfd);
    do_cleanups (cleanup);

  reply	other threads:[~2016-10-13 17:44 UTC|newest]

Thread overview: 16+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2016-09-13  9:05 Sangamesh Mallayya
2016-09-29 15:33 ` Ulrich Weigand
2016-09-30 14:15   ` Sangamesh Mallayya
2016-09-30 14:38     ` Ulrich Weigand
2016-10-04 13:19       ` Sangamesh Mallayya
2016-10-07 19:31         ` Ulrich Weigand
2016-10-08 13:15           ` Sangamesh Mallayya
2016-10-08 14:38             ` Ulrich Weigand
2016-10-10 12:11               ` Sangamesh Mallayya
2016-10-10 16:29                 ` Ulrich Weigand
2016-10-11  7:17                   ` Ulrich Weigand
2016-10-13 13:42                     ` Sangamesh Mallayya
2016-10-13 14:03                       ` Ulrich Weigand
2016-10-13 17:44                         ` Sangamesh Mallayya [this message]
2016-10-14 13:13                           ` Ulrich Weigand
     [not found] <OFBAE0EEF6.511F8BA2-ON6525802D.00305F69-6525802D.0031DA2D@LocalDomain>
2016-09-27 11:39 ` Sangamesh Mallayya

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=OF1BA61B31.92F7DDAC-ON6525804B.00611590-6525804B.0061615B@notes.na.collabserv.com \
    --to=sangamesh.swamy@in.ibm.com \
    --cc=gdb-patches@sourceware.org \
    --cc=uweigand@de.ibm.com \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).